@@ -51,19 +51,19 @@ ActionListItem::ActionListItem(QListBox *listbox, const QString &action, const Q
   setText(text);
 }
 
-ConfigDialog::ConfigDialog(QCString twn, QWidget *parent, const char *name) : QDialog(parent, name)
+ConfigDialog::ConfigDialog(QWidget *parent, const char *name) : QDialog(parent, name)
 {
-  topWidgetName = twn;
+  topWidgetName = parent->topLevelWidget()->name();
   config = new KConfig("metabarrc");
   iconConfig = new KConfig(locate("data", "metabar/iconsrc"));
 
-  setCaption("Metabar - " + i18n("Configuration"));
+  setCaption("Configuration - Metabar");
   setIcon(SmallIcon("metabar"));
 
-  ok = new KPushButton(i18n("OK"), this);
+  ok = new KPushButton(KStdGuiItem::ok(), this);
   connect(ok, SIGNAL(clicked()), this, SLOT(accept()));
   
-  cancel = new KPushButton(i18n("Cancel"), this);
+  cancel = new KPushButton(KStdGuiItem::cancel(), this);
   connect(cancel, SIGNAL(clicked()), this, SLOT(reject()));
   
   QTabWidget *tab = new QTabWidget(this);
@@ -72,10 +72,10 @@ ConfigDialog::ConfigDialog(QCString twn, QWidget *parent, const char *name) : QD
   config->setGroup("General");
   QWidget *general = new QWidget;
   
-  QGroupBox *entries_group = new QGroupBox(2, Qt::Horizontal, i18n("Entries"), general);
+  QGroupBox *entries_group = new QGroupBox(2, Qt::Horizontal, i18n("Items"), general);
   entries_group->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
   
-  QLabel *entries_label = new QLabel(i18n("Open with %1").arg("..."), entries_group);
+  QLabel *entries_label = new QLabel(i18n("Open with:"), entries_group);
   max_entries = new KIntSpinBox(entries_group);
   max_entries->setMinValue(1);
   max_entries->setMaxValue(99);
@@ -83,7 +83,7 @@ ConfigDialog::ConfigDialog(QCString twn, QWidget *parent, const char *name) : QD
   max_entries->setValue(config->readNumEntry("MaxEntries", 3));
   entries_label->setBuddy(max_entries);
   
-  QLabel *actions_label = new QLabel(i18n("Actions"), entries_group);
+  QLabel *actions_label = new QLabel(i18n("Actions:"), entries_group);
   max_actions = new KIntSpinBox(entries_group);
   max_actions->setMinValue(1);
   max_actions->setMaxValue(99);
@@ -98,27 +98,29 @@ ConfigDialog::ConfigDialog(QCString twn, QWidget *parent, const char *name) : QD
   animate = new QCheckBox(i18n("Animate resize"), appearance_group);
   animate->setChecked(config->readBoolEntry("AnimateResize", false));
   
-  servicemenus = new QCheckBox(i18n("Show Servicemenus"), appearance_group);
+  servicemenus = new QCheckBox(i18n("Show service menus"), appearance_group);
   servicemenus->setChecked(config->readBoolEntry("ShowServicemenus", true));
   
   //link page
   QWidget *links = new QWidget;
   
-  link_create = new KPushButton(i18n("Create"), links);
+  link_create = new KPushButton(i18n("New..."), links);
   connect(link_create, SIGNAL(clicked()), this, SLOT(createLink()));
   
   link_delete = new KPushButton(i18n("Delete"), links);
   connect(link_delete, SIGNAL(clicked()), this, SLOT(deleteLink()));
   
-  link_edit = new KPushButton(i18n("Edit"), links);
+  link_edit = new KPushButton(i18n("Edit..."), links);
   connect(link_edit, SIGNAL(clicked()), this, SLOT(editLink()));  
   
   link_up = new KPushButton(links);
-  link_up->setPixmap(SmallIcon("up"));
+  link_up->setIconSet(SmallIconSet("up"));
+  link_up->setEnabled(false);
   connect(link_up, SIGNAL(clicked()), this, SLOT(moveLinkUp()));
   
   link_down = new KPushButton(links);
-  link_down->setPixmap(SmallIcon("down"));
+  link_down->setIconSet(SmallIconSet("down"));
+  link_down->setEnabled(false);
   connect(link_down, SIGNAL(clicked()), this, SLOT(moveLinkDown()));
     
   link_list = new KListView(links);
@@ -128,6 +130,7 @@ ConfigDialog::ConfigDialog(QCString twn, QWidget *parent, const char *name) : QD
   link_list->addColumn(i18n("Name"));
   link_list->addColumn(i18n("Address"));
   connect(link_list, SIGNAL(doubleClicked(QListViewItem*)), this, SLOT(editLink(QListViewItem*)));
+  connect(link_list, SIGNAL(selectionChanged()), SLOT(updateArrows()));
   
   QWidget *actionPage = new QWidget;
   
@@ -147,8 +150,8 @@ ConfigDialog::ConfigDialog(QCString twn, QWidget *parent, const char *name) : QD
   
   QVBoxLayout *link_button_layout = new QVBoxLayout(0, 0, 5);
   link_button_layout->addWidget(link_create);
-  link_button_layout->addWidget(link_delete);
   link_button_layout->addWidget(link_edit);
+  link_button_layout->addWidget(link_delete);
   link_button_layout->addItem(new QSpacerItem(10, 10, QSizePolicy::Minimum, QSizePolicy::Expanding));
   link_button_layout->addWidget(link_up);
   link_button_layout->addWidget(link_down);
@@ -192,7 +195,7 @@ ConfigDialog::ConfigDialog(QCString twn, QWidget *parent, const char *name) : QD
   config->setGroup("General");
   QStringList actions = config->readListEntry("Actions");
   for(QStringList::Iterator it = actions.begin(); it != actions.end(); ++it){
-    if((*it).startsWith("metabar:")){
+    if((*it).startsWith("metabar/")){
       if((*it).right((*it).length() - 8) == "share"){
         QString text = i18n("Share");
       
@@ -284,10 +287,10 @@ void ConfigDialog::createLink()
   main->setCaption(i18n("Create Link"));
   main->setIcon(SmallIcon("metabar"));
   
-  KPushButton *ok = new KPushButton(i18n("OK"), main);
+  KPushButton *ok = new KPushButton(KStdGuiItem::ok(), main);
   connect(ok, SIGNAL(clicked()), main, SLOT(accept()));
   
-  KPushButton *cancel = new KPushButton(i18n("Cancel"), main);
+  KPushButton *cancel = new KPushButton(KStdGuiItem::cancel(), main);
   connect(cancel, SIGNAL(clicked()), main, SLOT(reject()));
   
   QLineEdit *name = new QLineEdit(i18n("New link"), main);
@@ -306,9 +309,9 @@ void ConfigDialog::createLink()
   
   QGridLayout *layout = new QGridLayout(0, 2, 3, 0, 5);
   layout->addWidget(icon, 0, 0);
-  layout->addWidget(new QLabel(i18n("Name"), main), 0, 1);
+  layout->addWidget(new QLabel(i18n("Name:"), main), 0, 1);
   layout->addWidget(name, 0, 2);
-  layout->addWidget(new QLabel(i18n("URL"), main), 1, 0);
+  layout->addWidget(new QLabel(i18n("URL:"), main), 1, 0);
   layout->addMultiCellWidget(url, 1, 1, 1, 2);
   
   QVBoxLayout *main_layout = new QVBoxLayout(main, 5, 5);
@@ -337,6 +340,7 @@ void ConfigDialog::createLink()
       item->setPixmap(0, icon);
       
       linkList.insert(item, new LinkEntry(name_str, url_str, icon_str));
+      updateArrows();
     }
   }
   
@@ -349,6 +353,7 @@ void ConfigDialog::deleteLink()
   if(item){
     linkList.remove(item);
     delete item;
+    updateArrows();
   }
 }
 
@@ -362,13 +367,13 @@ void ConfigDialog::editLink(QListViewItem *item)
 {
   if(item){  
     QDialog *main = new QDialog(this);
-    main->setCaption(i18n("Create Link"));
+    main->setCaption(i18n("Edit Link"));
     main->setIcon(SmallIcon("metabar"));
     
-    KPushButton *ok = new KPushButton(i18n("OK"), main);
+    KPushButton *ok = new KPushButton(KStdGuiItem::ok(), main);
     connect(ok, SIGNAL(clicked()), main, SLOT(accept()));
     
-    KPushButton *cancel = new KPushButton(i18n("Cancel"), main);
+    KPushButton *cancel = new KPushButton(KStdGuiItem::cancel(), main);
     connect(cancel, SIGNAL(clicked()), main, SLOT(reject()));
     
     QLineEdit *name = new QLineEdit(linkList[item]->name, main);
@@ -387,9 +392,9 @@ void ConfigDialog::editLink(QListViewItem *item)
     
     QGridLayout *layout = new QGridLayout(0, 2, 3, 0, 5);
     layout->addWidget(icon, 0, 0);
-    layout->addWidget(new QLabel(i18n("Name"), main), 0, 1);
+    layout->addWidget(new QLabel(i18n("Name:"), main), 0, 1);
     layout->addWidget(name, 0, 2);
-    layout->addWidget(new QLabel(i18n("URL"), main), 1, 0);
+    layout->addWidget(new QLabel(i18n("URL:"), main), 1, 0);
     layout->addMultiCellWidget(url, 1, 1, 1, 2);
     
     QVBoxLayout *main_layout = new QVBoxLayout(main, 5, 5);
@@ -458,6 +463,7 @@ void ConfigDialog::moveLinkUp()
       link_list->setSelected(newItem, TRUE);
       
       linkList.insert(newItem, new LinkEntry(name, url, icon_str));
+      updateArrows();
     }
   }
 }
@@ -488,6 +494,7 @@ void ConfigDialog::moveLinkDown()
       link_list->setSelected(newItem, TRUE);
       
       linkList.insert(newItem, new LinkEntry(name, url, icon_str));
+      updateArrows();
     }
   }
 }
@@ -522,5 +529,11 @@ void ConfigDialog::loadAvailableActions()
   }
   
   //metabar's own actions
-  ActionListItem *item = new ActionListItem(box, "metabar:share", i18n("Share"), SmallIcon("network"));
+  ActionListItem *item = new ActionListItem(box, "metabar/share", i18n("Share"), SmallIcon("network"));
+}
+
+void ConfigDialog::updateArrows()
+{
+  link_up->setEnabled( link_list->childCount()>1 && link_list->currentItem()!=link_list->firstChild() );
+  link_down->setEnabled( link_list->childCount()>1 && link_list->currentItem()!=link_list->lastItem() );
 }
